@@ -5,9 +5,13 @@
 #include <QNetworkAccessManager>
 #include <QDebug>
 #include <QListWidgetItem>
+#include "widgets/photoitem.h"
 #include "imageuploaddialog.h"
 #include "qfacebook.h"
 
+// Starts from 0, this means 4 columns
+#define MAX_COLUMNS 3
+
 namespace Ui {
     class AlbumWindow;
 }
@@ -31,31 +35,15 @@ private:
     QString albumId;
     QNetworkAccessManager *nam;
     QString albumCount;
+    QList<PhotoItem*> photos;
+    int column;
+    int row;
 
 private slots:
     void updateAlbum();
     void onReplyReceived();
-    void onImageProcessed(QString id, QPixmap pixmap);
     void uploadPhoto();
-};
-
-class Image : public QObject
-{
-    Q_OBJECT
-
-public:
-    explicit Image(QWidget *parent = 0, QListWidgetItem *item = 0);
-    ~Image();
-
-signals:
-    void imageProcessed(QString id, QPixmap image);
-
-private:
-    QString id;
-    QListWidgetItem *item;
-
-private slots:
-    void imageReceived();
+    void onPhotoItemClicked(PhotoItem*);
 };
 
 #endif // ALBUMWINDOW_H
