@@ -11,10 +11,19 @@ FriendsWindow::FriendsWindow(QWidget *parent, QString accessToken) :
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5StackedWindow);
     ui->friendsList->setIconSize(QSize(64, 64));
+#endif
+    ui->searchWidget->hide();
+#ifdef Q_WS_MAEMO_5
+    ui->searchHideButton->setIcon(QIcon::fromTheme("general_close"));
+#else
+    ui->searchHideButton->setText("X");
 #endif
     connect(nam, SIGNAL(finished(QNetworkReply*)), this, SLOT(onAvatarReplyFinished(QNetworkReply*)));
     connect(ui->friendsList, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(onFriendClicked(QListWidgetItem*)));
     connect(ui->actionRefresh, SIGNAL(triggered()), this, SLOT(updateFriends()));
+    connect(ui->searchEdit, SIGNAL(textChanged(QString)), this, SLOT(onSearchTextChanged(QString)));
+    connect(ui->searchHideButton, SIGNAL(clicked()), ui->searchWidget, SLOT(hide()));
+    connect(ui->searchHideButton, SIGNAL(clicked()), ui->searchEdit, SLOT(clear()));
 }
 
 FriendsWindow::~FriendsWindow()
@@ -95,6 +104,16 @@ void FriendsWindow::requestRecepientsList()
     disconnect(ui->friendsList, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(onFriendClicked(QListWidgetItem*)));
     connect(doneButton, SIGNAL(clicked()), this, SLOT(onRecepientsSelected()));
     ui->verticalLayout->addWidget(doneButton);
+    this->setWindowFlags(Qt::Dialog);
+    this->browseId("me");
+    this->show();
+}
+
+void FriendsWindow::requestFriend()
+{
+    disconnect(ui->friendsList, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(onFriendClicked(QListWidgetItem*)));
+    connect(ui->friendsList, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(onRecepientsSelected()));
+    this->setWindowFlags(Qt::Dialog);
     this->browseId("me");
     this->show();
 }
@@ -114,6 +133,35 @@ void FriendsWindow::onFriendClicked(QListWidgetItem *item)
     window->show();
 }
 
+void FriendsWindow::keyReleaseEvent(QKeyEvent *e)
+{
+    if (e->key() == Qt::Key_Enter || e->key() == Qt::Key_Left || e->key() == Qt::Key_Right || e->key() == Qt::Key_Backspace)
+        return;
+    else if ((e->key() == Qt::Key_Up || e->key() == Qt::Key_Down) && !ui->searchWidget->isHidden())
+        ui->friendsList->setFocus();
+    else {
+        ui->friendsList->clearSelection();
+        if (ui->searchWidget->isHidden())
+            ui->searchWidget->show();
+        if (!ui->searchEdit->hasFocus())
+            ui->searchEdit->setText(ui->searchEdit->text() + e->text());
+        ui->searchEdit->setFocus();
+    }
+}
+
+void FriendsWindow::onSearchTextChanged(QString text)
+{
+    for (int i=0; i < ui->friendsList->count(); i++) {
+        if (ui->friendsList->item(i)->text().toLower().indexOf(text.toLower()) == -1)
+            ui->friendsList->item(i)->setHidden(true);
+        else
+            ui->friendsList->item(i)->setHidden(false);
+    }
+
+    if (text.isEmpty())
+        ui->searchWidget->hide();
+}
+
 Friend::Friend (QWidget *parent, QString id) :
     userId(id)
 {
