@@ -7,6 +7,7 @@
 #include <QDebug>
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
+#include <QKeyEvent>
 #include <QListWidgetItem>
 #include "profilewindow.h"
 #include <qfacebook.h>
@@ -25,6 +26,10 @@ public:
     void browseId(QString id);
     void setToken(QString token);
     void requestRecepientsList();
+    void requestFriend();
+
+protected:
+    void keyReleaseEvent(QKeyEvent *);
 
 signals:
     void recepientsSelected(QList<QListWidgetItem*>);
@@ -44,6 +49,7 @@ private slots:
     void onRecepientsSelected();
     void onFriendClicked(QListWidgetItem*);
     void updateFriends();
+    void onSearchTextChanged(QString);
 };
 
 class Friend : public QObject
