@@ -13,7 +13,7 @@
 #endif
 
 /* TODO: Add Android define */
-#define perms "user_checkins,friends_checkins,create_event,user_events,rsvp_event,friends_events,user_groups,friends_groups,manage_pages,user_photos,friends_photos,read_stream,offline_access,publish_stream,read_mailbox,friends_birthday,friends_relationships,user_relationships,user_relationship_details,friends_relationship_details,user_location,friends_location,user_hometown,friends_hometown,user_activities,friends_activities,friends_status"
+#define perms "publish_checkins,user_checkins,friends_checkins,create_event,user_events,rsvp_event,friends_events,user_groups,friends_groups,manage_pages,user_photos,friends_photos,read_stream,offline_access,publish_stream,read_mailbox,friends_birthday,friends_relationships,user_relationships,user_relationship_details,friends_relationship_details,user_location,friends_location,user_hometown,friends_hometown,user_activities,friends_activities,friends_status"
 #if defined (Q_WS_MAEMO_5) || defined (Q_WA_S60)
     #define authUrl "https://www.facebook.com/dialog/oauth?client_id=198401840201289&redirect_uri=https://www.facebook.com/connect/login_success.html&scope=%1&response_type=token&display=touch"
 #else
