@@ -51,11 +51,19 @@ MainWindow::~MainWindow()
 void MainWindow::connectSignals()
 {
     connect(ui->actionAbout_Qt, SIGNAL(triggered()), qApp, SLOT(aboutQt()));
+    connect(ui->actionAbout, SIGNAL(triggered()), this, SLOT(showAbout()));
+    connect(ui->actionAdd_a_favorite, SIGNAL(triggered()), this, SLOT(onAddToFavoritesClicked()));
     connect(ui->actionLogout, SIGNAL(triggered()), this, SLOT(logout()));
     connect(ui->listWidget, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(onItemActivated(QListWidgetItem*)));
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
 }
 
+void MainWindow::showAbout()
+{
+    AboutDialog *about = new AboutDialog(this);
+    about->show();
+}
+
 void MainWindow::onItemActivated(QListWidgetItem *item)
 {
     if (item->text() == tr("News Feed")) {
@@ -74,8 +82,10 @@ void MainWindow::onItemActivated(QListWidgetItem *item)
         window->show();
 #endif
     } else if (item->text() == tr("Photos")) {
-        if (!albumsWindow)
+        if (!albumsWindow) {
             albumsWindow = new AlbumsWindow(this, this->accessToken);
+            albumsWindow->browseAlbums("me");
+        }
 #ifdef Q_WS_S60
         albumsWindow->showMaximized();
 #else
@@ -130,6 +140,11 @@ void MainWindow::onItemActivated(QListWidgetItem *item)
 #else
         placesWindow->show();
 #endif
+    } else if (!item->data(Qt::UserRole).isNull()) {
+        ProfileWindow *window = new ProfileWindow(this, this->accessToken);
+        window->setWindowTitle(item->text());
+        window->browseProfile(item->data(Qt::UserRole).toString());
+        window->show();
     }
 }
 
@@ -222,6 +237,28 @@ void MainWindow::onGetMyIdReply()
     connect(notificationsDialog, SIGNAL(gotNotificationsCount(int)), this, SLOT(onGotNotificationCount(int)));
 }
 
+void MainWindow::onAddToFavoritesClicked()
+{
+    FriendsWindow *window = new FriendsWindow(this, accessToken);
+    window->setAttribute(Qt::WA_DeleteOnClose);
+    connect(window, SIGNAL(recepientsSelected(QList<QListWidgetItem*>)), this, SLOT(onFreidnSelected(QList<QListWidgetItem*>)));
+    window->requestRecepientsList();
+    window->setWindowFlags(Qt::Dialog);
+    window->show();
+}
+
+void MainWindow::onFreidnSelected(QList<QListWidgetItem*> list)
+{
+    if (list.count() == 0)
+        return;
+
+    QListWidgetItem *item = list.first();
+    QListWidgetItem *favItem = new QListWidgetItem(ui->listWidget);
+    favItem->setText(item->text());
+    favItem->setData(Qt::UserRole, item->data(Qt::UserRole));
+    favItem->setIcon(item->icon());
+}
+
 void MainWindow::deleteWindows()
 {
     if (newsFeedWindow) {
