@@ -66,7 +66,7 @@ void MessagesWindow::onReplyReceived()
         item->setUserId(userId);
         item->setName(from);
         item->setMessage(message);
-        item->getPixmapFromUrl(QString("https://graph.facebook.com/%1/picture&access_token=%2").arg(id, accessToken));
+        item->getPixmapFromUrl(QString("https://graph.facebook.com/%1/picture&access_token=%2").arg(userId, accessToken));
         item->setId(id);
         ui->scrollLayout->addWidget(item);
         messages.append(item);
