@@ -7,6 +7,7 @@
 #include <qfacebook.h>
 #include "messageview.h"
 #include "composemessage.h"
+#include "newsfeedpost.h"
 
 namespace Ui {
     class MessagesWindow;
@@ -25,12 +26,14 @@ private:
     QFacebook *qfacebook;
     QFacebookReply *reply;
     QString accessToken;
+    QList<NewsFeedPost*> messages;
+    QNetworkAccessManager *nam;
 
 private slots:
     void updateMessages();
     void onReplyReceived();
     void onNewMessageButtonClicked();
-    void onItemActivated(QListWidgetItem *);
+    void onMessageClicked(QString id);
 };
 
 #endif // MESSAGESWINDOW_H
