@@ -45,7 +45,7 @@ void NewsFeedWindow::postUpdate(QString text, QString link, QString video)
 {
     QByteArray data;
     if (!text.isEmpty()) {
-        data.append("message=" + text);
+        data.append("message=" + text.toUtf8());
         if (!link.isEmpty() || !video.isEmpty())
             data.append("&");
     }
@@ -56,9 +56,19 @@ void NewsFeedWindow::postUpdate(QString text, QString link, QString video)
     }
     if (!video.isEmpty())
         data.append("video=" + video);
-    qDebug() << data;
 
-    qfacebook->putObject("me", "feed", data);
+    statusReply = qfacebook->putObject("me", "feed", data);
+    if (statusReply)
+        connect(statusReply, SIGNAL(finished()), this, SLOT(onStatusUpdateReplyFinished()));
+}
+
+void NewsFeedWindow::onStatusUpdateReplyFinished()
+{
+#ifdef Q_WS_MAEMO_5
+    QMaemo5InformationBox::information(this, tr("Status update posted"));
+#else
+    QMessageBox::information(this, tr("Success"), tr("Status update posted"));
+#endif
 }
 
 void NewsFeedWindow::updateNewsFeed()
