@@ -7,6 +7,9 @@
 #include <QNetworkAccessManager>
 #include <QSettings>
 #include <QScrollBar>
+#ifndef Q_WS_MAEMO_5
+    #include <QMessageBox>
+#endif
 #include "newstatusupdatedialog.h"
 #include "singlepostwindow.h"
 #include "newsfeedpost.h"
@@ -30,6 +33,7 @@ private:
     QString accessToken;
     QFacebook *qfacebook;
     QFacebookReply *reply;
+    QFacebookReply *statusReply;
     QNetworkAccessManager *nam;
     QList<NewsFeedPost*> posts;
     QString myId;
@@ -43,6 +47,7 @@ private slots:
     void orientationChanged();
     void onCommentButtonClicked(QString, QString, QString);
     void onNameClicked(QString, QString);
+    void onStatusUpdateReplyFinished();
 };
 
 #endif // NEWSFEEDWINDOW_H
