@@ -20,6 +20,12 @@ public:
     void showPhoto(QString photoId);
     void setPhoto(QString filename);
     void showPhotoFromId(QString id);
+    void setPixmapFromUrl(QString url);
+    void setPhotoId(QString id);
+    void setUserId(QString userId);
+    void setPixmap(QPixmap pixmap);
+    void setComments(QVariantList comments);
+    void setTags(QVariantList tags);
 
 private:
     Ui::PhotoWindow *ui;
@@ -28,6 +34,10 @@ private:
     QString accessToken;
     QNetworkAccessManager *nam;
     QString photoId;
+    QString m_userId;
+    QVariantList m_comments;
+    QVariantList m_tags;
+    QList<QWidget*> commentsList;
 
 private slots:
     void onReplyReceived();
