@@ -1,5 +1,6 @@
 #include "profilewindow.h"
 #include "ui_profilewindow.h"
+#include "albumswindow.h"
 
 ProfileWindow::ProfileWindow(QWidget *parent, QString token) :
     QMainWindow(parent),
@@ -16,6 +17,7 @@ ProfileWindow::ProfileWindow(QWidget *parent, QString token) :
     connect(ui->writeOnWallEdit, SIGNAL(clicked()), this, SLOT(onTextBoxClicked()));
     connect(ui->actionRefresh, SIGNAL(triggered()), this, SLOT(updateProfile()));
     connect(ui->userAvatar, SIGNAL(clicked()), this, SLOT(onAvatarClicked()));
+    connect(ui->actionPhotos, SIGNAL(triggered()), this, SLOT(onPhotosClicked()));
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
     this->orientationChanged();
 }
@@ -104,6 +106,14 @@ void ProfileWindow::updateProfile()
     this->browseProfile(this->profileId);
 }
 
+void ProfileWindow::onPhotosClicked()
+{
+    AlbumsWindow *albums = new AlbumsWindow(this, accessToken);
+    albums->setAttribute(Qt::WA_DeleteOnClose);
+    albums->browseAlbums(profileId);
+    albums->show();
+}
+
 void ProfileWindow::onAvatarReceived()
 {
     QUrl redir = this->avatarReply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
@@ -123,6 +133,11 @@ void ProfileWindow::setAvatar(QPixmap avatar)
     ui->userAvatar->setIcon(QIcon(avatar));
 }
 
+void ProfileWindow::onNewsFeedPostDestroyed(QObject *object)
+{
+    posts.removeOne((NewsFeedPost*)object);
+}
+
 void ProfileWindow::onReplyReceived()
 {
     if (!posts.isEmpty()) {
@@ -147,6 +162,7 @@ void ProfileWindow::onReplyReceived()
     listData = jsonData.toMap().value("data").toList();
     foreach(jsonData, listData) {
         NewsFeedPost *post = new NewsFeedPost(ui->scrollArea, accessToken, qfacebook, nam);
+        connect(post, SIGNAL(destroyed(QObject*)), this, SLOT(onNewsFeedPostDestroyed(QObject*)));
         connect(post, SIGNAL(nameClicked(QString,QString)), this, SLOT(onNameClicked(QString,QString)));
         connect(post, SIGNAL(commentButtonClicked(QString,QString,QString)),
                 this, SLOT(onCommentButtonClicked(QString,QString,QString)));
@@ -223,7 +239,7 @@ void ProfileWindow::onPostToWall(QString text, QString link, QString video)
     ui->writeOnWallEdit->setEnabled(false);
 
     if (!text.isEmpty()) {
-        dataToPost.append("message=" + text);
+        dataToPost.append("message=" + text.toUtf8());
         if (!link.isEmpty() || !video.isEmpty())
             dataToPost.append("&");
     }
