@@ -54,6 +54,8 @@ private slots:
     void orientationChanged();
     void onNameClicked(QString id, QString name);
     void onCommentButtonClicked(QString id, QString comments, QString likes);
+    void onNewsFeedPostDestroyed(QObject*);
+    void onPhotosClicked();
 };
 
 #endif // PROFILEWINDOW_H
