@@ -1,5 +1,6 @@
 #include "singlepostwindow.h"
 #include "ui_singlepostwindow.h"
+#include "profilewindow.h"
 
 SinglePostWindow::SinglePostWindow(QWidget *parent, QString token) :
     QMainWindow(parent),
@@ -114,6 +115,8 @@ void SinglePostWindow::onReplyReceived()
 
     if (!gotMainPost) {
         NewsFeedPost *post = new NewsFeedPost(this, accessToken, qfacebook, nam);
+        connect(post, SIGNAL(nameClicked(QString,QString)), this, SLOT(onNameClicked(QString,QString)));
+        connect(post, SIGNAL(destroyed()), this, SLOT(close()));
         post->setCommentMode(true);
         post->setDeletable(deletable);
         post->setMessage(message);
@@ -131,6 +134,8 @@ void SinglePostWindow::onReplyReceived()
     listData = jsonData.toMap().value("comments").toMap().value("data").toList();
     foreach(jsonData, listData) {
         NewsFeedPost *post = new NewsFeedPost(ui->commentsWidget, accessToken, qfacebook, nam);
+        connect(post, SIGNAL(nameClicked(QString,QString)), this, SLOT(onNameClicked(QString,QString)));
+        connect(post, SIGNAL(destroyed(QObject*)), this, SLOT(onPostDestroyed(QObject*)));
         post->setCommentMode(true);
         QString name = jsonData.toMap().value("from").toMap().value("name").toString();
         QString userId = jsonData.toMap().value("from").toMap().value("id").toString();
@@ -179,6 +184,19 @@ void SinglePostWindow::onReplyReceived()
     }
 }
 
+void SinglePostWindow::onPostDestroyed(QObject *object)
+{
+    posts.removeOne((NewsFeedPost*)object);
+}
+
+void SinglePostWindow::onNameClicked(QString id, QString name)
+{
+    ProfileWindow *window = new ProfileWindow(this, accessToken);
+    window->setWindowTitle(name);
+    window->browseProfile(id);
+    window->show();
+}
+
 void SinglePostWindow::onPostButtonClicked()
 {
     if (ui->replyEdit->text().isEmpty()) {
@@ -191,7 +209,7 @@ void SinglePostWindow::onPostButtonClicked()
     }
 
     QByteArray data;
-    data.append(QString("message=%1").arg(ui->replyEdit->text()));
+    data.append("message=" + ui->replyEdit->text().toUtf8());
     this->commentReply = qfacebook->putObject(this->postId, "comments", data);
     if (this->commentReply)
         connect(commentReply, SIGNAL(finished()), this, SLOT(onCommentReplyReceived()));
