@@ -4,6 +4,8 @@
 #include <QWidget>
 #include <QNetworkAccessManager>
 #include <QMouseEvent>
+#include <QPainter>
+#include <QDebug>
 #include <qfacebook.h>
 
 namespace Ui {
@@ -22,11 +24,15 @@ public:
     void setUserId(QString id);
     void setAvatarUrl(QString url);
     void setTime(QString time);
+    void setCheckinId(QString id);
+    void setCoordinates(double longitude, double latitude);
+    void setPlaceId(QString id);
     bool isPressed();
 
 protected:
     void mousePressEvent(QMouseEvent *);
     void mouseReleaseEvent(QMouseEvent *);
+    void paintEvent(QPaintEvent *);
 
 signals:
     void pressed();
@@ -39,7 +45,10 @@ private:
     QNetworkAccessManager *nam;
     QNetworkReply *avatarReply;
     QString m_userId;
-    QString checkinId;
+    QString m_checkinId;
+    QString m_placeId;
+    double m_longitude;
+    double m_latitude;
     bool m_pressed;
 
 private slots:
